Changelog
=========

.. changelog::
    :changelog-url: https://pypitoken.readthedocs.io/en/stable/#changelog
    :github: https://github.com/ewjoachim/pypitoken/releases/
    :pypi: https://pypi.org/project/pypitoken/
